---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**

Concise description of the problem ...

**To Reproduce**

Steps to reproduce the behavior ...

**Expected behavior**

Concise description of what you expected to happen ...

**Screenshots**

If applicable, add screenshots to help explain your problem.

**Environment (please complete the following information):**

 - OS: [e.g. iOS, Linux, Windows, ... with version]
- `qmat` version :
- installation : [how did you install the package]


**Additional details**

Add any other details about the problem here (you can be more verbose here ...)
